@@ -62,7 +62,10 @@ class MidiFileSynth:
         track.prepend_bpm(60)
         self.create_midifile(track)
         if self.__child_pid:
-            os.kill(self.__child_pid, signal.SIGQUIT)
+            try:
+                os.kill(self.__child_pid, signal.SIGKILL)
+            except OSError:
+                pass
             os.wait()
             self.__child_pid = None
         pid = os.fork()
