@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -91,14 +91,14 @@ class PianoOctaveWithAccelName(PianoKeyboard):
             g = self.m_keyboard.add('group')
             g.add('text', text=keys[[0, 2, 4, 5, 7, 9, 11][x]],
                   x = (x+0.5)*self.m_w, y = self.m_h-20,
-                  font="-*-*-*-*-*--*-240-*-*-*-*-*-*", fill_color='black')
-            g.connect('event', self.on_event, 
+                  font="-*-helvetica-medium-r-*-*-25-*-*-*-*-*-*-*", fill_color='black')
+            g.connect('event', self.on_event,
                    mpd.notename_to_int(['c', 'd', 'e', 'f', 'g', 'a', 'b'][x]))
         for x in range(5):
             g = self.m_keyboard.add('group')
             g.add('text', text=keys[[1, 3, 6, 8, 10][x]],
                   x = [1, 2, 4, 5, 6][x]*self.m_w-2, y = self.m_h2-20,
-                  font="-*-*-*-*-*--*-240-*-*-*-*-*-*", fill_color='white')
+                  font="-*-helvetica-medium-r-*-*-25-*-*-*-*-*-*-*", fill_color='white')
             g.connect('event', self.on_event,
                 mpd.notename_to_int(['cis', 'dis', 'fis', 'gis', 'ais'][x]))
     def on_button_press_event(self, group, event, midi_int):
