@@ -7,7 +7,9 @@
 # This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
 # implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-
+"""
+I used this to display the saved statistics in $HOME/.solfegeX.Y/
+"""
 import pickle, sys
 for fn in sys.argv[1:]:
     f = open(fn, "r")
